"""Visionlabs core mappings"""

from ..enums.accounts import AccountTargets
from ..enums.attributes import (
    ClothingColor,
    Deepfake,
    Emotion,
    Ethnic,
    Liveness,
    LowerGarmentType,
    Mask,
    PrimitiveClothingColor,
    SleeveLength,
    TemporaryAttributeMatchTargets,
    TemporaryAttributeTargets,
)
from ..enums.events import EventLocations, EventTargets
from ..enums.faces import FaceTargets
from ..enums.general_events import GeneralEventTargets
from ..utils.functions import convertEnumToSnakeDict

# dict: map ethnicities to numbers
ETHNIC_MAP = convertEnumToSnakeDict(Ethnic)
# dict: map emotion to numbers
EMOTION_MAP = convertEnumToSnakeDict(Emotion)
# dict: map mask to numbers
MASK_MAP = convertEnumToSnakeDict(Mask)
# dict: event target map
EVENT_TARGET_MAP = convertEnumToSnakeDict(EventTargets)
# dict: event target map
EVENT_LOCATION_MAP = convertEnumToSnakeDict(EventLocations)
# dict: general event target map
GENERAL_EVENT_TARGET_MAP = convertEnumToSnakeDict(GeneralEventTargets)
# dict: face target map
FACE_TARGET_MAP = convertEnumToSnakeDict(FaceTargets)
# dict: accounts target map
ACCOUNTS_TARGET_MAP = convertEnumToSnakeDict(AccountTargets)
# dict: temporary attribute target map
TEMPORARY_ATTRIBUTE_TARGET_MAP = convertEnumToSnakeDict(TemporaryAttributeTargets)
# dict: temporary attribute target map
TEMPORARY_ATTRIBUTE_MATCH_TARGET_MAP = convertEnumToSnakeDict(TemporaryAttributeMatchTargets)
# List[str]: list of allowed columns for csv report by clusterization event task
CLUSTERIZATION_REPORT_EVENT_COLUMNS = list(
    target for target in EVENT_TARGET_MAP if target not in ("account_id", "event_id", "location")
) + list(EVENT_LOCATION_MAP)
# List[str]: list of allowed columns for csv report by clusterization face task
CLUSTERIZATION_REPORT_FACE_COLUMNS = ["user_data", "create_time", "lists", "external_id", "avatar", "event_id"]
# List[str]: list of default columns for csv report by clusterization event task
CLUSTERIZATION_REPORT_EVENT_COLUMNS_DEFAULTS = ["event_id"] + [
    column
    for column in CLUSTERIZATION_REPORT_EVENT_COLUMNS
    if column not in ("account_id", "face_detections", "match_result", "attach_result", "tags", "body_detections")
]
# List[str]: list of default columns for csv report by clusterization face task
CLUSTERIZATION_REPORT_FACE_COLUMNS_DEFAULTS = ["face_id"] + [
    column for column in CLUSTERIZATION_REPORT_FACE_COLUMNS if column not in ("lists",)
]
# List[str]: list of allowed columns for exporter event task
EXPORTER_EVENT_COLUMNS = list(target for target in EVENT_TARGET_MAP if target not in ("account_id", "location")) + list(
    EVENT_LOCATION_MAP
)
# List[str]: list of default columns for exporter event task
EXPORTER_EVENT_COLUMNS_DEFAULTS = [
    column
    for column in EXPORTER_EVENT_COLUMNS
    if column not in ("account_id", "face_detections", "match_result", "attach_result", "tags", "body_detections")
]
# List[str]: list of allowed columns for exporter face task
EXPORTER_FACE_COLUMNS = ["face_id", "user_data", "create_time", "lists", "external_id", "avatar", "event_id"]
# List[str]: list of default columns for exporter face task
EXPORTER_FACE_COLUMNS_DEFAULTS = [column for column in EXPORTER_FACE_COLUMNS if column not in ("lists",)]
# dict: map liveness to numbers
LIVENESS_MAP = convertEnumToSnakeDict(Liveness)
# dict: map deepfake to numbers
DEEPFAKE_MAP = convertEnumToSnakeDict(Deepfake)
# dict: sleeve length map
SLEEVE_LENGTH_MAP = convertEnumToSnakeDict(SleeveLength)
# dict: clothing color map
CLOTHING_COLOR_MAP = convertEnumToSnakeDict(ClothingColor)
# dict: clothing color map
PRIMITIVE_CLOTHING_COLOR_MAP = convertEnumToSnakeDict(PrimitiveClothingColor)
# dict: garment type map
LOWER_GARMENT_MAP = convertEnumToSnakeDict(LowerGarmentType)
